package org.mortinious.fortress;

import java.io.*;
import java.util.ArrayList;
import java.util.Random;

import org.bukkit.entity.Player;
import org.bukkit.plugin.java.JavaPlugin;

public class FortMain extends JavaPlugin{
	
	public void onEnable(){	
		updateClaims();
		detectors = new ArrayList<FortDetector>();
		getServer().getPluginManager().registerEvents(new FortListener(this), this);
		System.out.println(getCommand("fort"));
		getCommand("fort").setExecutor(new FortressCommandExecutor(this));
		rand = new Random();
	}
	
	public void onDisable(){
		updateSaveFile();
		
	}
	
	public void updateSaveFile(){
		try {
		    BufferedWriter out = new BufferedWriter(new FileWriter("claims.fc"));
		    for(int i = 0; i < claims.size(); i++){
		    	FortClaim c = claims.get(i);
		    	out.write(c.name+";"+c.x1+";"+c.y1+";"+c.x2+";"+c.y2);
		    	out.newLine();
			    for(int j = 0; j < c.members.size(); j++){
			    	if(c.admins.contains(c.members.get(i))){
				    	out.write("*"+c.members.get(i)+";");
			    	}
			    	else{
				    	out.write(c.members.get(i)+";");
			    	}
			    }
		    }
		    out.close();
		} catch (IOException e) {
		}
	}
	
	public void updateClaims(){
		claims = new ArrayList<FortClaim>();
		try {
		    BufferedReader in = new BufferedReader(new FileReader("claims.fc"));
		    String claim;
		    String members;
		    for(int i = 0; (claim = in.readLine()) != null; i++) {
		    	members = in.readLine();
		    	
		    	String[] s = claim.split(";");
		    	FortClaim c = new FortClaim(this, Integer.parseInt(s[1]), Integer.parseInt(s[2]), Integer.parseInt(s[3]), Integer.parseInt(s[4]), s[0]);
		    	s = members.split(";");
		    	for(int j = 0; j < s.length; j++){
		    		if(s[i].startsWith("*")){
		    			c.addMember(s[i].substring(1));
		    			c.addAdmin(s[i].substring(1));
		    		}
		    		else{
		    			c.addMember(s[i]);
		    		}
		    	}
		    	reclaim(c);
		    }
		    in.close();
		} catch (IOException e) {
		}
	}
	
	public Boolean canBreakBlock(int i, int j, String s){
		for(int n = 0; n< claims.size(); n++){
			if(!claims.get(n).canBreakBlocks(i, j, s)){
				return false;
			}
		}
		return true;
	}
	
	public void activateDetector(FortDetector detector, Player player){
		detector.activate(player);
	}
	
	public void deactivateDetector(FortDetector detector, String s){
		if(!detector.isTriggered(this,s)){
			detector.deactivate();
		}
	}
	
	public FortDetector getDetector(int i, int j, int k){
		for(int n = 0; n< detectors.size(); n++){
			if(detectors.get(n).isCoordOnDetector(i,j,k)){
				return detectors.get(n);
			}
		}
		return null;
	}
	
	public void addDetector(String s, int i, int j, int k, int mode, int dir){
		if(getDetector(i,j,k)==null){
			FortClaim c = getClaimByCoord(i,k);
			if(c != null){
				if(c.hasMember(s)){
					detectors.add(new FortDetector(i,j,k,mode,dir,c,this));
					System.out.println(detectors.size());
				}
			}
		}
	}
	
	public FortClaim getClaimByCoord(int i, int j){
		if(getClaimIdByCoord(i, j)!=-1){
			return claims.get(getClaimIdByCoord(i, j));
		}else{
			return null;
		}
	}
	
	public FortClaim getClaimByMember(String s){
		if(getClaimIdByMember(s)!=-1){
			return claims.get(getClaimIdByMember(s));
		}else{
			return null;
		}
	}
	
	public int getClaimIdByCoord(int i, int j){
		for(int n = 0; n< claims.size(); n++){
			if(claims.get(n).isCoordOnClaim(i, j)){
				return n;
			}
		}
		return -1;
	}
	
	public int getClaimIdByMember(String s){
		for(int n = 0; n< claims.size(); n++){
			if(claims.get(n).hasMember(s)){
				return n;
			}
		}
		return -1;
	}
	
	public Boolean claimLand(String owner, int i, int j, String name){
		for(int n = 0; n< claims.size(); n++){
			if(claims.get(n).isCoordOnClaim(i, j)){
				this.getServer().getPlayer(owner).sendMessage("There is already a claim covering this block");
				return false;
			}
			else{
			if(claims.get(n).hasMember(owner)){
				this.getServer().getPlayer(owner).sendMessage("You already have one claim. Please remove the claim before placing a new one.");
				return false;
			}}
		}
		FortClaim claim = new FortClaim(this,owner,i,j);
		claim.setName(name);
		claims.add(claim);
		getServer().getPlayer(owner).sendMessage("You have created the claim "+claim.name+" at "+i+", "+j+".");
		updateSaveFile();
		return true;
	}
	
	public Boolean expandClaimByPos(String name, int i, int j){
		for(int n = 0; n< claims.size(); n++){
			if(claims.get(n).isCoordOnClaim(i, j)){
				if(claims.get(n).hasMember(name)){
					this.getServer().getPlayer(name).sendMessage("Your claim is already covering this block");
					return false;
				}else{
					this.getServer().getPlayer(name).sendMessage("There is another claim covering this block");
					return false;
				}
			}
			else if(claims.get(n).hasAdmin(name)){
				claims.get(n).expand(i, j);
				getServer().getPlayer(name).sendMessage("Your claim has been expanded to "+i+", "+j);
				updateSaveFile();
				return true;
			}
			else if(claims.get(n).hasMember(name)){
				this.getServer().getPlayer(name).sendMessage("You need to be an admin to expand your claim");
				return false;
			}
		}
		this.getServer().getPlayer(name).sendMessage("You dont belong to any claim");
		return false;
	}
	
	public void removeClaim(String name){
		claims.remove(getClaimIdByMember(name));
		updateSaveFile();
	}
	
	public void reclaim(FortClaim c){
		claims.add(c);
	}

	public ArrayList<FortClaim> claims;
	public ArrayList<FortDetector> detectors;
	public Random rand;
}
