package org.mortinious.fortress;

import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

public class FortressCommandExecutor implements CommandExecutor{
	
	public FortressCommandExecutor(FortMain m){
		main = m;
	}
	
	public boolean onCommand(CommandSender sender, Command cmd, String cmdLabel, String[] args) {
		Player player = (Player) sender;
		if(args.length==0){
			player.sendMessage("Type /fort help fort available commands.");
			return false;
		}
		
		if(args[0].equalsIgnoreCase("claim")) {
			String claimName;
			if(args.length == 1){
				claimName = player.getName()+"'s settlement";
			}else{
				claimName = args[1];
			}
			if(main.claimLand(player.getName(), player.getLocation().getBlockX(), player.getLocation().getBlockZ(), claimName)){
				return false;
			}
			return false;
		}
		
		if(args[0].equalsIgnoreCase("expand")) {
			main.expandClaimByPos(player.getName(), player.getLocation().getBlockX(), player.getLocation().getBlockZ());
		}
		
		if(args[0].equalsIgnoreCase("invite")) {
			if(args.length==1){
				if(main.getClaimByMember(player.getName())!=null){
					player.sendMessage("Usage: /fort invite <players name>");
					if(!main.getClaimByMember(player.getName()).hasAdmin(player.getName())){
						player.sendMessage("You are not privilaged to invite members to your claim.");
					}else if(main.getClaimByMember(player.getName()).hasMember(args[1])){
						player.sendMessage(args[1]+" already belong to your claim.");
					}else{
						main.getClaimByMember(player.getName()).addMember(args[1]);
					}
				
				}else{
					player.sendMessage("You dont have a claim to invite "+args[1]+" to.");
				}
			}
		}
		
		if(args[0].equalsIgnoreCase("promote")) {
			if(args.length==1){
				if(main.getClaimByMember(player.getName())!=null){
					player.sendMessage("Usage: /fort promote <members name>");
					if(!main.getClaimByMember(player.getName()).hasAdmin(player.getName())){
						player.sendMessage("You are not privilaged to promote this member.");
					}else if(!main.getClaimByMember(player.getName()).hasMember(args[1])){
						player.sendMessage(args[1]+" don't belong to your claim.");
					}else{
						main.getClaimByMember(player.getName()).addAdmin(args[1]);
					}
				
				}else{
					player.sendMessage("You dont have a claim to promote members in.");
				}
			}
		}
		
		if(args[0].equalsIgnoreCase("members")) {
			FortClaim claim = main.getClaimByCoord(player.getLocation().getBlockX(),player.getLocation().getBlockZ());
			if(claim == null){
				player.sendMessage("The block you are standing on is unclaimed.");
				return false;
			}
			player.sendMessage("Following players are residents of "+claim.name+".");
			for(int i = 0; i < claim.members.size(); i++){
				player.sendMessage(claim.members.get(i));
			}
			return false;
		}
		
		if(args[0].equalsIgnoreCase("help")) {
			player.sendMessage("Avaiable commands are:");
			player.sendMessage("	Claim 	- Claims a 9x9 area");
			player.sendMessage("	Info 	- Gives you info of the claim you are in");
			player.sendMessage("	Members	- Lists all members of the claim you are in");
			player.sendMessage("	MyClaim - Gives you info of your claim");
			player.sendMessage("	Expand 	- Expands your claim");
			player.sendMessage("	Remove 	- Removes the claim");
			player.sendMessage("	Help 	- Shows this text");
			return false;
		}
		
		if(args[0].equalsIgnoreCase("info")) {
			FortClaim claim = main.getClaimByCoord(player.getLocation().getBlockX(),player.getLocation().getBlockZ());
			
			if(claim == null){
				player.sendMessage("The block you are standing on is unclaimed.");
				return false;
			}
			
			player.sendMessage("Name: "+claim.name);
			player.sendMessage("Size: "+(Math.abs(claim.x1-claim.x2))+"X"+(Math.abs(claim.y1-claim.y2)));
			player.sendMessage("Center: "+Math.round(claim.x1+(claim.x1-claim.x2)/2)+", "+Math.round(claim.y1+(claim.y1-claim.y2)));
			
			for(int i = 0; i < claim.members.size(); i++){
				if(claim.members.get(i).equals(player.getName())){
					player.sendMessage("You are a resident of this claim");
				}
			}
			return false;
		}
		
		if(args[0].equalsIgnoreCase("detector")){
			main.addDetector(player.getName(), player.getLocation().getBlockX(), player.getLocation().getBlockY(), player.getLocation().getBlockZ(), 0, 0);
		}
		
		if(args[0].equalsIgnoreCase("myclaim")) {
			FortClaim claim = main.getClaimByMember(player.getName());
			
			if(claim == null){
				player.sendMessage("You dont have a claim yet.");
				return false;
			}
			
			player.sendMessage("Name: "+claim.name);
			player.sendMessage("Size: "+(Math.abs(claim.x1-claim.x2))+"X"+(Math.abs(claim.y1-claim.y2)));
			player.sendMessage("Center: "+Math.round(claim.x1+(claim.x1-claim.x2)/2)+", "+Math.round(claim.y1+(claim.y1-claim.y2)));
			
			return false;
		}
		
		if(args[0].equalsIgnoreCase("rename")) {
			if(args.length == 1){
				player.sendMessage("You need to specify a new name");
				return false;
			}
			FortClaim claim = main.getClaimByMember(player.getName());
			
			if(claim == null){
				player.sendMessage("You dont have a claim yet.");
				return false;
			}
			player.sendMessage(claim.name+" is renamed to "+args[1]);
			claim.name=args[1];
			main.updateSaveFile();
			return false;
		}
		
		if(args[0].equalsIgnoreCase("remove")) {
			FortClaim claim = main.getClaimByMember(player.getName());
			
			if(claim == null){
				player.sendMessage("You dont have a claim yet.");
				return false;
			}
			
			main.removeClaim(player.getName());
			player.sendMessage("Your claim has now been removed.");
			main.updateSaveFile();
			return false;
		}
		
		return false;
	}
	
	private FortMain main;
}

